%bcond_with soxr
%bcond_with ffmpeg
%bcond_with tsmf

%if %{with soxr}
%global cfg_with_soxr ON
%else
%global cfg_with_soxr OFF
%endif

%if %{with ffmpeg}
%global cfg_with_ffmpeg ON
%else
%global cfg_with_ffmpeg OFF
%endif

Summary:        Free implementation of the Remote Desktop Protocol (RDP)
Name:           freerdp
Version:        2.11.6
Release:        2%{?dist}
License:        ASL 2.0
URL:            http://www.freerdp.com/
Source0:        https://github.com/FreeRDP/FreeRDP/archive/%{version}/%{name}-%{version}.tar.gz
Patch0001:      CVE-2024-32660.patch

BuildRequires: gcc gcc-c++ alsa-lib-devel cmake cups-devel gsm-devel lame-devel libicu-devel libjpeg-turbo-devel
BuildRequires: libX11-devel libXcursor-devel libXdamage-devel libXext-devel libXi-devel libXinerama-devel
BuildRequires: libxkbfile-devel libXrandr-devel libXtst-devel libXv-devel pam-devel xmlto zlib-devel
BuildRequires: pkgconfig(cairo) pkgconfig(libpcsclite) pkgconfig(libpulse) pkgconfig(libsystemd) pkgconfig(libusb-1.0)
BuildRequires: pkgconfig(openssl) pkgconfig(wayland-client) pkgconfig(wayland-scanner) pkgconfig(xkbcommon) pkgconfig(krb5)
%if %{with tsmf}
BuildRequires: pkgconfig(dbus-1) pkgconfig(dbus-glib-1) pkgconfig(glib-2.0)
BuildRequires: pkgconfig(gstreamer-1.0) pkgconfig(gstreamer-base-1.0) pkgconfig(gstreamer-app-1.0)
BuildRequires: pkgconfig(gstreamer-audio-1.0) pkgconfig(gstreamer-fft-1.0) pkgconfig(gstreamer-pbutils-1.0)
BuildRequires: pkgconfig(gstreamer-video-1.0)
%endif
%if %{with soxr}
BuildRequires:  pkgconfig(soxr)
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec) pkgconfig(libavutil)
%endif

Provides:       xfreerdp = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       libwinpr = %{version}-%{release}

%description
The xfreerdp & wlfreerdp Remote Desktop Protocol (RDP) clients from the FreeRDP project.

xfreerdp & wlfreerdp can connect to RDP servers such as Microsoft Windows machines, xrdp and
VirtualBox.

%package        libs
Summary:        Core libraries implementing the RDP protocol
Requires:       libwinpr = %{version}-%{release}
Provides:       %{name}-plugins = %{version}-%{release}
%description    libs
libfreerdp-core can be embedded in applications.

libfreerdp-channels and libfreerdp-kbd might be convenient to use in X applications together with
libfreerdp-core.

libfreerdp-core can be extended with plugins handling RDP channels.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release} pkgconfig cmake

%description    devel
The %{name}-devel package contains libraries and header files for developing applications that use
%{name}-libs.

%package        server
Summary:        Server support for %{name}
Requires:       libwinpr = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description    server
The %{name}-server package contains servers which can export a desktop via the RDP protocol.

%package -n     libwinpr
Summary:        Windows Portable Runtime
Provides:       %{name}-libwinpr = %{version}-%{release}

%description -n libwinpr
WinPR provides API compatibility for applications targeting non-Windows environments. When on
Windows, the original native API is being used instead of the equivalent WinPR implementation,
without having to modify the code using it.

%package -n     libwinpr-devel
Summary:        Windows Portable Runtime development files
Requires:       libwinpr = %{version}-%{release} pkgconfig cmake

%description -n libwinpr-devel
The %{name}-libwinpr-devel package contains libraries and header files for developing applications
that use %{name}-libwinpr.

%prep
%autosetup -p1 -n %{name}-%{version}

find . -name "*.h" -exec chmod 664 {} \;
find . -name "*.c" -exec chmod 664 {} \;

%build
%cmake %{?_cmake_skip_rpath} \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
    -DWITH_ALSA=ON \
    -DWITH_CAIRO=ON \
    -DWITH_CUPS=ON \
    -DWITH_CHANNELS=ON -DBUILTIN_CHANNELS=OFF \
    -DWITH_CLIENT=ON \
    -DWITH_DIRECTFB=OFF \
    -DWITH_FFMPEG=%{?cfg_with_ffmpeg} \
    -DWITH_GSM=ON \
    -DWITH_GSSAPI=ON \
%if %{with %tsmf}
    -DWITH_GSTREAMER_1_0=ON -DWITH_GSTREAMER_0_10=OFF \
    -DCHANNEL_TSMF=ON \
%endif
    -DWITH_ICU=ON \
    -DWITH_IPP=OFF \
    -DWITH_JPEG=ON \
    -DWITH_LAME=ON \
    -DWITH_MANPAGES=ON \
    -DWITH_OPENH264=OFF \
    -DWITH_OPENSSL=ON \
    -DWITH_PCSC=ON \
    -DWITH_PULSE=ON \
    -DWITH_SERVER=ON \
    -DWITH_SERVER_INTERFACE=ON \
    -DWITH_SHADOW_X11=ON \
    -DWITH_SHADOW_MAC=ON \
    -DWITH_SOXR=%{?cfg_with_soxr} \
    -DWITH_WAYLAND=ON \
    -DWITH_X11=ON \
    -DWITH_X264=%OFF \
    -DWITH_XCURSOR=ON \
    -DWITH_XEXT=ON \
    -DWITH_XKBFILE=ON \
    -DWITH_XI=ON \
    -DWITH_XINERAMA=ON \
    -DWITH_XRENDER=ON \
    -DWITH_XTEST=ON \
    -DWITH_XV=ON \
    -DWITH_ZLIB=ON \
%ifarch x86_64
    -DWITH_SSE2=ON \
    -DWITH_VAAPI=%{?cfg_with_ffmpeg} \
%else
    -DWITH_SSE2=OFF \
%endif
    %{nil}

%cmake_build

%install
%cmake_install

find %{buildroot} -name "*.a" -delete

%files
%{_bindir}/winpr-hash
%{_bindir}/winpr-makecert
%{_bindir}/wlfreerdp
%{_bindir}/xfreerdp
%{_mandir}/man1/winpr-hash.1*
%{_mandir}/man1/winpr-makecert.1*
%{_mandir}/man1/wlfreerdp.1*
%{_mandir}/man1/xfreerdp.1*

%files libs
%license LICENSE
%doc README.md ChangeLog
%{_libdir}/freerdp2/
%{_libdir}/libfreerdp-client2.so.*
%{_libdir}/libfreerdp-server2.so.*
%{_libdir}/libfreerdp-shadow2.so.*
%{_libdir}/libfreerdp-shadow-subsystem2.so.*
%{_libdir}/libfreerdp2.so.*
%{_libdir}/libuwac0.so.*
%{_mandir}/man7/wlog.*

%files devel
%{_includedir}/freerdp2
%{_includedir}/uwac0
%{_libdir}/cmake/FreeRDP2
%{_libdir}/cmake/FreeRDP-Client2
%{_libdir}/cmake/FreeRDP-Server2
%{_libdir}/cmake/FreeRDP-Shadow2
%{_libdir}/cmake/uwac0
%{_libdir}/libfreerdp-client2.so
%{_libdir}/libfreerdp-server2.so
%{_libdir}/libfreerdp-shadow2.so
%{_libdir}/libfreerdp-shadow-subsystem2.so
%{_libdir}/libfreerdp2.so
%{_libdir}/libuwac0.so
%{_libdir}/pkgconfig/freerdp2.pc
%{_libdir}/pkgconfig/freerdp-client2.pc
%{_libdir}/pkgconfig/freerdp-server2.pc
%{_libdir}/pkgconfig/freerdp-shadow2.pc
%{_libdir}/pkgconfig/uwac0.pc

%files server
%{_bindir}/freerdp-proxy
%{_bindir}/freerdp-shadow-cli
%{_mandir}/man1/freerdp-shadow-cli.1*

%files -n libwinpr
%license LICENSE
%doc README.md ChangeLog
%{_libdir}/libwinpr2.so.*
%{_libdir}/libwinpr-tools2.so.*

%files -n libwinpr-devel
%{_includedir}/winpr2
%{_libdir}/cmake/WinPR2
%{_libdir}/libwinpr2.so
%{_libdir}/libwinpr-tools2.so
%{_libdir}/pkgconfig/winpr2.pc
%{_libdir}/pkgconfig/winpr-tools2.pc

%changelog
* Mon May 06 2024 Fanjun Kong <fanjunkong@tencent.com> - 2.11.6-2
- Fix CVE-2024-32660

* Mon May 06 2024 Fanjun Kong <fanjunkong@tencent.com> - 2.11.6-1
- Upgrade to upstream version 2.11.6
- CVE-2024-32041 [Low[ OutOfBound Read in zgfx_decompress_segment
- CVE-2024-32039 [Moderate] Integer overflow & OutOfBound Write in clear_decompress_residual_data
- CVE-2024-32040 [Low] integer underflow in nsc_rle_decode
- CVE-2024-32458 [Low] OutOfBound Read in planar_skip_plane_rle
- CVE-2024-32459 [Low] OutOfBound Read in ncrush_decompress
- CVE-2024-32460 [Low] OutOfBound Read in interleaved_decompress

* Thu Apr 11 2024 Fanjun Kong <fanjunkong@tencent.com> - 2.11.2-2
- Fix CVE-2024-22211

* Thu Oct 19 2023 Xiaojie Chen <jackxjchen@tencent.com> - 2.11.2-1
- Upgrade to upstream version 2.11.2
- Fix CVE-2023-40589,CVE-2023-40569,CVE-2023-40567,CVE-2023-40188
- Fix CVE-2023-40186,CVE-2023-40181,CVE-2023-39356,CVE-2023-39354
- Fix CVE-2023-39353,CVE-2023-39352,CVE-2023-39351,CVE-2023-39350
- Fix CVE-2022-41877,CVE-2022-39347,CVE-2022-39320,CVE-2022-39319
- Fix CVE-2022-39318,CVE-2022-39317,CVE-2022-39316
- Remove dbus, glib and gstreamer requirements

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.8.1-6
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 2.8.1-5
- Rebuilt for icu 73.2

* Mon Jul 17 2023 Xiaojie Chen <jackxjchen@tencent.com> - 2.8.1-4
- Rebuilt for gstreamer1-plugins-base 1.22.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.8.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.8.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 9 2023 Shuo Wang <abushwang@tencent.com> - 2.8.1-1
- initial build
